@@ -5,6 +5,7 @@ from wagtail.documents.blocks import DocumentChooserBlock
 from wagtail.images.blocks import ImageChooserBlock
 from wagtail.core.rich_text import RichText
 from wagtail.core import blocks
+from wagtail.snippets.blocks import SnippetChooserBlock
 
 from webspace.cms.blocks.mocker import Mocker
 from webspace.cms import constants
@@ -25,7 +26,7 @@ def add_id_attribute(match):
     n = match.group(1)
     text_content = match.group(2)
     id = slugify(text_content)
-    return f'<h{n} id="{id}">{text_content}</h{n}>'
+    return f'<h{n} id="titles-{id}">{text_content}</h{n}>'
 
 
 def with_heading_ids(self):
@@ -97,6 +98,13 @@ class ButtonBlock(blocks.StructBlock):
         label = "Button"
 
 
+class FormBlock(blocks.StructBlock):
+    form = SnippetChooserBlock('cms.Form', required=True)
+
+    class Meta:
+        template = '%s/common/form.html' % constants.BLOCK_TEMPLATES_PATH
+        label = "Form"
+
 
 class EntryBlock(blocks.StructBlock):
     bg_desktop = blocks.StreamBlock(
