@@ -1,9 +1,8 @@
-from .media_text import MediaTextEntry
+from .component_text import ComponentTextEntry
 from .svg import SvgEntry
 from .text import TextEntry
 from .image import ImageEntry
 from .cards import CardsEntry
-from .first_content import FirstContentEntry
 from .grid_info import GridInfoEntry
 from .medias_line import MediasLineEntry
 from .timeline import TimeLineEntry
@@ -11,3 +10,7 @@ from .buttons import ButtonsEntry
 from .articles import ArticlesEntry
 from .embed import EmbedEntry
 from .calendly import CalendlyEntry
+from .table import TableEntry
+from .numbers import NumbersEntry
+from .accordion import AccordionEntry
+from .form import FormEntry
