@@ -2,29 +2,36 @@ import json
 import random
 from io import BytesIO
 import requests
+
 from django.core.files.images import ImageFile
 from django.utils import lorem_ipsum
 
 from wagtail.images.models import Image
+from wagtail.contrib.forms.models import FORM_FIELD_CHOICES
 
 from webspace.loader import get_model
 from webspace.cms import constants
 
-Menu = get_model('cms', 'Menu')
-MenuItem = get_model('cms', 'MenuItem')
-MyDocument = get_model('cms', 'MyDocument')
 
 def title():
-    return lorem_ipsum.words(random.randint(5, 15))
+    return lorem_ipsum.words(random.randint(2, 15))
 
 
-def text(rand_min=100, rand_max=200):
+def text(rand_min=5, rand_max=20):
     return lorem_ipsum.words(random.randint(rand_min, rand_max))
 
 
 class Mocker(object):
-    h = f"""
-        {title()}
+    MyDocument = get_model('cms', 'MyDocument')
+
+    p = f"""
+        <p>{title()}</p>
+        """
+
+    h = f"""{title()}"""
+
+    h1 = f"""
+        <h1>{title()}</h1>
         """
 
     xs = f"""
@@ -45,33 +52,6 @@ class Mocker(object):
         <p>{text(50, 50)}</p>
         """
 
-    big = f"""
-        <h2>{title()}</h2>
-        <h3>{title()}</h3>
-        <h4>{title()}</h4>
-        <hr/>
-        <p>{title()}</p>
-        <ol>
-            <li>{title()}</li>
-            <li>{title()}</li>
-            <li>{title()}</li>
-            <li>{title()}</li>
-        </ol>
-        <p>{title()}</p>
-        <p><b>{title()}</b><i>{title()}</i></p>
-        <p><i>{title()}</i></p>
-        <ul>
-            <li>{title()}</li>
-            <li>{title()}</li>
-            <li>{title()}</li>
-            <li>{title()}</li>
-        </ul>
-        <p></p>
-        <p></p>
-        <p>{text()}</p>
-        <p><a href="#">{title()}</a>. {text()}</p><p><br/></p>
-        """
-
     example = f"""
         <h1>H1 -> Lorem ipsum dolor sit amet, consectetur adipiscing elit</h1>
         <h2>H2 -> Lorem ipsum dolor sit amet, consectetur adipiscing elit</h2>
@@ -331,6 +311,34 @@ class Mocker(object):
     }
     default_url = "http://localhost:8080"
 
+    @property
+    def big(self):
+        return f"""
+                <h2>{title()}</h2>
+                <h3>{title()}</h3>
+                <h4>{title()}</h4>
+                <hr/>
+                <p>{title()}</p>
+                <ol>
+                    <li>{title()}</li>
+                    <li>{title()}</li>
+                    <li>{title()}</li>
+                    <li>{title()}</li>
+                </ol>
+                <p>{title()}</p>
+                <p><b>{title()}</b><i>{title()}</i></p>
+                <p><i>{title()}</i></p>
+                <ul>
+                    <li>{title()}</li>
+                    <li>{title()}</li>
+                    <li>{title()}</li>
+                    <li>{title()}</li>
+                </ul>
+                <p></p>
+                <p></p>
+                <p>{text()}</p>
+                <p><a href="#">{title()}</a>. {text()}</p><p><br/></p>
+                """
     @staticmethod
     def button(m_type=constants.BUTTON_PRIMARY_FULL):
         return {
@@ -355,6 +363,9 @@ class Mocker(object):
 
     @staticmethod
     def menu(page, menu_id=None):
+        Menu = get_model('cms', 'Menu')
+        MenuItem = get_model('cms', 'MenuItem')
+
         if not menu_id:
             menu = Menu.objects.create(
                 help_text=page.title,
@@ -372,35 +383,45 @@ class Mocker(object):
 
     @staticmethod
     def add_menu(page, menu_id, footer=True):
+        Navigation = get_model('cms', 'Navigation')
+        nav, created = Navigation.objects.get_or_create(help_text='demo')
+        if created:
+            nav.save()
+
 
         # Header
 
         header_menus = []
-        for header_menu in page.header_menus:
-            header_menus.append({
-                'type': 'menu',
-                'value': header_menu.value.id
-            })
+        for header_menu in nav.header_menus:
+            if menu_id != header_menu.value.id:
+                header_menus.append({
+                    'type': 'menu',
+                    'value': header_menu.value.id
+                })
         header_menus.append({
             'type': 'menu',
             'value': menu_id
         })
-        page.header_menus = json.dumps(header_menus)
+        nav.header_menus = json.dumps(header_menus)
 
         # Footer
 
         if footer:
             footer_menus = []
-            for footer_menu in page.footer:
-                footer_menus.append({
-                    'type': 'menu',
-                    'value': footer_menu.value.id
-                })
+            for footer_menu in nav.footer:
+                if menu_id != footer_menu.value.id:
+                    footer_menus.append({
+                        'type': 'menu',
+                        'value': footer_menu.value.id
+                    })
             footer_menus.append({
                 'type': 'menu',
                 'value': menu_id
             })
-            page.footer = json.dumps(footer_menus)
+            nav.footer = json.dumps(footer_menus)
+
+        nav.save()
+        page.navigation = nav
         page.save()
 
     @staticmethod
@@ -414,3 +435,34 @@ class Mocker(object):
         }]
         page.header_buttons = json.dumps(header_buttons)
         page.save()
+
+    @staticmethod
+    def get_form(key, nb_fields=None, head_text=True):
+        Form = get_model('cms', 'Form')
+        FormField = get_model('cms', 'FormField')
+        IconSnippet = get_model('cms', 'IconSnippet')
+
+        form, created = Form.objects.get_or_create(help_text=key)
+        counter = 0
+        if created:
+            if head_text:
+                form.text = Mocker.text_first_content
+            form.save()
+            for field_type in FORM_FIELD_CHOICES:
+                form_field, created = FormField.objects.get_or_create(
+                    field_type=field_type[0],
+                    form_id=form.id
+                )
+                if created:
+                    form_field.label = Mocker.h + str(counter)
+                    form_field.help_text = Mocker.h
+                    form_field.choices = 'loreum,dolor,sit,amet'
+                    form_field.placeholder = 'loreum dolor sit amet'
+                    form_field.required = False
+                    form_field.icon = IconSnippet.objects.first()
+                    form_field.save()
+                counter += 1
+                if nb_fields:
+                    if counter >= nb_fields:
+                        break
+        return form
