@@ -2,19 +2,20 @@ from django.db import models
 from django.utils.functional import cached_property
 from django.http import HttpResponse
 from django.conf import settings
-from wagtail.admin.edit_handlers import MultiFieldPanel, StreamFieldPanel
+from wagtail.admin.edit_handlers import MultiFieldPanel, StreamFieldPanel, PageChooserPanel
 from wagtail.images.edit_handlers import ImageChooserPanel
+from wagtail.snippets.edit_handlers import SnippetChooserPanel
 from wagtail.core.fields import StreamField
 from wagtail.core.models import Page
-from wagtail.snippets.blocks import SnippetChooserBlock
-from wagtail.admin.edit_handlers import FieldPanel
+from wagtail.admin.edit_handlers import FieldPanel, InlinePanel
 from wagtail.core.utils import camelcase_to_underscore
+from modelcluster.fields import ParentalKey
+from wagtail.core.models import Orderable
 
 from webspace.cms.amp.mixins import AmpMixin
 from webspace.cms.amp.utils import amp_mode_active
 from webspace.cms import constants
 from webspace.cms.blocks.schemas import HowTo, FAQPage
-from webspace.cms.blocks.common import ButtonBlock
 from webspace.loader import get_model, get_class
 
 #  Classes
@@ -23,21 +24,54 @@ ArticlesEntry = get_class('cms.blocks.entries', 'ArticlesEntry')
 ButtonsEntry = get_class('cms.blocks.entries', 'ButtonsEntry')
 CardsEntry = get_class('cms.blocks.entries', 'CardsEntry')
 EmbedEntry = get_class('cms.blocks.entries', 'EmbedEntry')
-FirstContentEntry = get_class('cms.blocks.entries', 'FirstContentEntry')
 GridInfoEntry = get_class('cms.blocks.entries', 'GridInfoEntry')
 ImageEntry = get_class('cms.blocks.entries', 'ImageEntry')
-MediaTextEntry = get_class('cms.blocks.entries', 'MediaTextEntry')
+ComponentTextEntry = get_class('cms.blocks.entries', 'ComponentTextEntry')
 MediasLineEntry = get_class('cms.blocks.entries', 'MediasLineEntry')
 SvgEntry = get_class('cms.blocks.entries', 'SvgEntry')
 TextEntry = get_class('cms.blocks.entries', 'TextEntry')
 TimeLineEntry = get_class('cms.blocks.entries', 'TimeLineEntry')
 CalendlyEntry = get_class('cms.blocks.entries', 'CalendlyEntry')
+TableEntry = get_class('cms.blocks.entries', 'TableEntry')
+NumbersEntry = get_class('cms.blocks.entries', 'NumbersEntry')
+AccordionEntry = get_class('cms.blocks.entries', 'AccordionEntry')
+FormEntry = get_class('cms.blocks.entries', 'FormEntry')
+
 SocialShare = get_class('cms.blocks.static', 'SocialShare')
 
 
 #  Models
 Menu = get_model('cms', 'Menu')
 IconSnippet = get_model('cms', 'IconSnippet')
+Navigation = get_model('cms', 'Navigation')
+
+
+class AMultiLanguagePage(Orderable):
+    parent = ParentalKey('GenericPage', related_name='language_pages')
+    language = models.CharField(
+        choices=constants.LANGUAGES,
+        default='',
+        blank=True,
+        max_length=100,
+        help_text="Language de la page"
+    )
+    page = models.ForeignKey(
+        Page,
+        null=True,
+        blank=True,
+        on_delete=models.SET_NULL,
+        related_name='+',
+        verbose_name="Page",
+    )
+
+    panels = [
+        FieldPanel("language"),
+        PageChooserPanel("page"),
+    ]
+
+    class Meta:
+        app_label = 'cms'
+        abstract = True
 
 
 class AGenericPage(Page):
@@ -63,26 +97,26 @@ class AGenericPage(Page):
         help_text="Ajoute la page dans le sitemap et génère un schéma Breadcrumb",
     )
 
-    header_menus = StreamField([
-        ('menu', SnippetChooserBlock(Menu, required=False)),
-    ], blank=True)
-
-    header_buttons = StreamField([
-        ('button', ButtonBlock())
-    ], blank=True)
-
     schemas = StreamField([
         ('how_to', HowTo()),
         ('faq_page', FAQPage()),
     ], blank=True)
 
+    navigation = models.ForeignKey(
+        Navigation,
+        null=True,
+        blank=True,
+        on_delete=models.SET_NULL,
+        related_name='+',
+        verbose_name="Navigation",
+    )
+
     body = StreamField([
-        ('first_content', FirstContentEntry()),
         ('svg', SvgEntry()),
         ('image', ImageEntry()),
         ('text', TextEntry()),
         ('cards', CardsEntry()),
-        ('media_text', MediaTextEntry()),
+        ('component_text', ComponentTextEntry()),
         ('grid_info', GridInfoEntry()),
         ('medias_line', MediasLineEntry()),
         ('timeline', TimeLineEntry()),
@@ -90,11 +124,11 @@ class AGenericPage(Page):
         ('calendly', CalendlyEntry()),
         ('articles', ArticlesEntry()),
         ('embed', EmbedEntry()),
-        ('social_share', SocialShare())
-    ], blank=True)
-
-    footer = StreamField([
-        ('menu', SnippetChooserBlock(Menu, required=False)),
+        ('social_share', SocialShare()),
+        ('table', TableEntry()),
+        ('accordion', AccordionEntry()),
+        ('numbers', NumbersEntry()),
+        ('form', FormEntry()),
     ], blank=True)
 
     content_panels = [
@@ -116,9 +150,8 @@ class AGenericPage(Page):
         FieldPanel('title'),
         FieldPanel('slug'),
         FieldPanel('theme'),
-        StreamFieldPanel('header_menus'),
-        StreamFieldPanel('header_buttons'),
-        StreamFieldPanel('footer'),
+        SnippetChooserPanel('navigation'),
+        InlinePanel("language_pages", label="Pages multi-language")
     ]
 
     subpage_types = [
@@ -134,6 +167,11 @@ class AGenericPage(Page):
         context = super(AGenericPage, self).get_context(request)
         context['debug'] = str(settings.DEBUG)
         context['icons'] = IconSnippet.get_context()
+        context['studio'] = {
+            'name': constants.STUDIO_NAME,
+            'email': constants.STUDIO_EMAIL,
+            'url': constants.STUDIO_URL,
+        }
         return context
 
     @cached_property
@@ -149,7 +187,15 @@ class AGenericPage(Page):
     def get_sitemap_urls(self, request=None):
         if not self.breadcrumb:
             return []
-        return super().get_sitemap_urls(request)
+        urls = super().get_sitemap_urls(request)
+        if self.language_pages:
+            urls[-1]['alternatives'] = []
+            for language_page in self.language_pages.all():
+                urls[-1]['alternatives'].append({
+                    'language': language_page.language,
+                    'href': language_page.page.get_full_url(),
+                })
+        return urls
 
     def get_url_parts(self, *args, **kwargs):
         urls = super().get_url_parts(*args, **kwargs)
